1.0.0 API documentation: GLM_EXT_vector_ulp

| 1.0.0 API documentation

Functions
GLM_EXT_vector_ulp
Stable extensions

## Functions
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, int64, Q > | floatDistance (vec< L, double, Q > const &x, vec< L, double, Q > const &y)
| Return the distance in the number of ULP between 2 double-precision floating-point scalars. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, int, Q > | floatDistance (vec< L, float, Q > const &x, vec< L, float, Q > const &y)
| Return the distance in the number of ULP between 2 single-precision floating-point scalars. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | nextFloat (vec< L, T, Q > const &x)
| Return the next ULP value(s) after the input value(s). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | nextFloat (vec< L, T, Q > const &x, int ULPs)
| Return the value(s) ULP distance after the input value(s). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | nextFloat (vec< L, T, Q > const &x, vec< L, int, Q > const &ULPs)
| Return the value(s) ULP distance after the input value(s). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | prevFloat (vec< L, T, Q > const &x)
| Return the previous ULP value(s) before the input value(s). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | prevFloat (vec< L, T, Q > const &x, int ULPs)
| Return the value(s) ULP distance before the input value(s). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | prevFloat (vec< L, T, Q > const &x, vec< L, int, Q > const &ULPs)
| Return the value(s) ULP distance before the input value(s). More...

## Detailed Description

Allow the measurement of the accuracy of a function against a reference implementation. This extension works on floating-point data and provide results in ULP.

Include <glm/ext/vector_ulp.hpp> to use the features of this extension.

See also
  GLM_EXT_scalar_ulp
  GLM_EXT_scalar_relational
  GLM_EXT_vector_relational

## Function Documentation

## ◆ floatDistance() [1/2]

GLM_FUNC_DECL vec<L, int64, Q> glm::floatDistance | ( | vec< L, double, Q > const & | x,
|  | vec< L, double, Q > const & | y
| ) |  |

Return the distance in the number of ULP between 2 double-precision floating-point scalars.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp

## ◆ floatDistance() [2/2]

GLM_FUNC_DECL vec<L, int, Q> glm::floatDistance | ( | vec< L, float, Q > const & | x,
|  | vec< L, float, Q > const & | y
| ) |  |

Return the distance in the number of ULP between 2 single-precision floating-point scalars.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp

## ◆ nextFloat() [1/3]

GLM_FUNC_DECL vec<L, T, Q> glm::nextFloat | ( | vec< L, T, Q > const & | x | ) |

Return the next ULP value(s) after the input value(s).

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp

## ◆ nextFloat() [2/3]

GLM_FUNC_DECL vec<L, T, Q> glm::nextFloat | ( | vec< L, T, Q > const & | x,
|  | int | ULPs
| ) |  |

Return the value(s) ULP distance after the input value(s).

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp

## ◆ nextFloat() [3/3]

GLM_FUNC_DECL vec<L, T, Q> glm::nextFloat | ( | vec< L, T, Q > const & | x,
|  | vec< L, int, Q > const & | ULPs
| ) |  |

Return the value(s) ULP distance after the input value(s).

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp

## ◆ prevFloat() [1/3]

GLM_FUNC_DECL vec<L, T, Q> glm::prevFloat | ( | vec< L, T, Q > const & | x | ) |

Return the previous ULP value(s) before the input value(s).

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp

## ◆ prevFloat() [2/3]

GLM_FUNC_DECL vec<L, T, Q> glm::prevFloat | ( | vec< L, T, Q > const & | x,
|  | int | ULPs
| ) |  |

Return the value(s) ULP distance before the input value(s).

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp

## ◆ prevFloat() [3/3]

GLM_FUNC_DECL vec<L, T, Q> glm::prevFloat | ( | vec< L, T, Q > const & | x,
|  | vec< L, int, Q > const & | ULPs
| ) |  |

Return the value(s) ULP distance before the input value(s).

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point
  Q | Value from qualifier enum

See also
  GLM_EXT_scalar_ulp